@@ -1,18 +1,24 @@
-use tanoshi_lib::prelude::{Param, SortByParam, SortOrderParam};
+use tanoshi_lib::prelude::Param;
 use tanoshi_vm::extension_bus::ExtensionBus;
 
-pub async fn test(bus: ExtensionBus) -> Result<(), Box<dyn std::error::Error>> {
+pub async fn test(
+    bus: ExtensionBus,
+    selector: Option<String>,
+) -> Result<(), Box<dyn std::error::Error>> {
     for detail in bus.list().await? {
+        if let Some(selector) = selector.clone() {
+            if detail.name != selector {
+                continue;
+            }
+        }
+
         println!("Test {}", detail.name);
 
-        let param = Param {
-            keyword: None,
-            genres: None,
-            page: None,
-            sort_by: Some(SortByParam::LastUpdated),
-            sort_order: Some(SortOrderParam::Desc),
-            auth: None,
-        };
+        print!("Test get supported filters ");
+        let _ = bus.filters(detail.id).await?;
+        println!("ok");
+
+        let param = Param::default();
 
         print!("Test get_manga_list ");
         let manga = bus.get_manga_list(detail.id, param).await?;
